==> autokreso-mailchimp-0.1.0-0751b2.tar: test/Entity/MailingList/ContactTest.php <==
<?php
namespace AkTest\Mailchimp\Entity\MailingList;

use Ak\Mailchimp\Entity\MailingList\Contact;
use AkTest\Mailchimp\AbstractTestCase;
use Zend\Hydrator\HydratorInterface;
use Zend\Hydrator\HydratorPluginManager;
use Zend\ServiceManager\PluginManagerInterface;

final class ContactTest extends AbstractTestCase
{
    public function testHydratorCanExchangeEntity()
    {
        $container = $this->getContainer();
        /** @var PluginManagerInterface $hydrators */
        $hydrators = $container->get(HydratorPluginManager::class);
        /** @var HydratorInterface $hydrator */
        $hydrator = $hydrators->get(Contact::class);

        $data = [
            'company' => 'Neka firma d.o.o.',
            'address1' => 'Ulica i kućni broj',
            'address2' => 'Kat i stan',
            'city' => 'Grad',
            'state' => 'Županija',
            'zip' => 'Poštanski broj',
            'country' => 'Država',
            'phone' => 'Telefonski broj',
        ];

        /** @var Contact $contact */
        $contact = $hydrator->hydrate($data, new Contact());

        $this->assertEquals($data['company'], $contact->getCompany());
        $this->assertEquals($data['address1'], $contact->getAddress1());
        $this->assertEquals($data['address2'], $contact->getAddress2());
        $this->assertEquals($data['city'], $contact->getCity());
        $this->assertEquals($data['state'], $contact->getState());
        $this->assertEquals($data['zip'], $contact->getZip());
        $this->assertEquals($data['country'], $contact->getCountry());
        $this->assertEquals($data['phone'], $contact->getPhone());

        $extracted = $hydrator->extract($contact);

        $this->assertEquals($data, $extracted);
    }
}

==> autokreso-mailchimp-0.1.4-44891a.tar: test/Entity/MailingList/ContactTest.php <==
<?php
namespace AkTest\Mailchimp\Entity\MailingList;

use Ak\Mailchimp\Entity\MailingList\Contact;
use AkTest\Mailchimp\AbstractTestCase;
use Laminas\Hydrator\HydratorInterface;
use Laminas\Hydrator\HydratorPluginManager;
use Laminas\ServiceManager\PluginManagerInterface;

final class ContactTest extends AbstractTestCase
{
    public function testHydratorCanExchangeEntity()
    {
        $container = $this->getContainer();
        /** @var PluginManagerInterface $hydrators */
        $hydrators = $container->get(HydratorPluginManager::class);
        /** @var HydratorInterface $hydrator */
        $hydrator = $hydrators->get(Contact::class);

        $data = [
            'company' => 'Neka firma d.o.o.',
            'address1' => 'Ulica i kućni broj',
            'address2' => 'Kat i stan',
            'city' => 'Grad',
            'state' => 'Županija',
            'zip' => 'Poštanski broj',
            'country' => 'Država',
            'phone' => 'Telefonski broj',
        ];

        /** @var Contact $contact */
        $contact = $hydrator->hydrate($data, new Contact());

        $this->assertEquals($data['company'], $contact->getCompany());
        $this->assertEquals($data['address1'], $contact->getAddress1());
        $this->assertEquals($data['address2'], $contact->getAddress2());
        $this->assertEquals($data['city'], $contact->getCity());
        $this->assertEquals($data['state'], $contact->getState());
        $this->assertEquals($data['zip'], $contact->getZip());
        $this->assertEquals($data['country'], $contact->getCountry());
        $this->assertEquals($data['phone'], $contact->getPhone());

        $extracted = $hydrator->extract($contact);

        $this->assertEquals($data, $extracted);
    }
}
